@@ -3,24 +3,15 @@
 # DESCRIPTION
 #   Driver module that encapsulates the details of formatting a LaTeX document
 #
-# AUTHOR
-#   Andrew Ford <andrew@ford-mason.co.uk>  (current maintainer)
-#
-# COPYRIGHT
-#   Copyright (C) 2009-2013 Ford & Mason Ltd.  All Rights Reserved.
-#   Copyright (C) 2006-2007 Andrew Ford.  All Rights Reserved.
-#   Portions Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-#
-#   This module is free software; you can redistribute it and/or
-#   modify it under the same terms as Perl itself.
-#
 
 package LaTeX::Driver;
 
 use strict;
 use warnings;
 
-use base 'Class::Accessor';
+use 5.008005;
+
+use parent 'Class::Accessor';
 use Cwd;                                # from PathTools
 use English qw( -no_match_vars );       # standard Perl class
 use Exception::Class ( 'LaTeX::Driver::Exception' );
@@ -31,15 +22,12 @@ use File::Slurp;
 use File::Spec;                         # from PathTools
 use IO::File;                           # from IO
 use Readonly;
-
-BEGIN {
-    require IPC::ShellCmd
-        unless $OSNAME eq 'MSWin32';
-}
+use File::pushd;                        # temporary cwd changes
+use Capture::Tiny qw(capture);
 
 Readonly our $DEFAULT_MAXRUNS => 10;
 
-our $VERSION = 0.20_02;
+our $VERSION = "1.1.0";
 
 __PACKAGE__->mk_accessors( qw( basename basedir basepath options
                                source output tmpdir format timeout stderr
@@ -54,7 +42,7 @@ our $DEBUGPREFIX;
 
 # LaTeX executable paths set at installation time by the Makefile.PL
 
-our @PROCESSORS      = qw(xelatex lulaatex pdflatex latex);
+our @PROCESSORS      = qw(xelatex lualatex pdflatex latex);
 our @AUXILLARY_PROGS = qw(bibtex makeindex);
 our @POSTPROCESSORS  = qw(dvips dvipdfm ps2pdf pdf2ps);
 our @PROGRAM_NAMES   = (@PROCESSORS, @AUXILLARY_PROGS, @POSTPROCESSORS);
@@ -79,9 +67,15 @@ our %FORMATTERS  = (
     pdf        => [ 'xelatex' ],
     'pdf(pdflatex)' => [ 'pdflatex' ],
     'pdf(xelatex)'  => [ 'xelatex' ],
+    'pdf(lualatex)'  => [ 'lualatex' ],
+    'ps(xelatex)'  => [ 'xelatex', 'pdf2ps' ],
+    'ps(lualatex)'  => [ 'lualatex', 'pdf2ps' ],
     'pdf(dvi)'      => [ 'latex', 'dvipdfm' ],
     'pdf(ps)'       => [ 'latex', 'dvips', 'ps2pdf' ],
     'ps(pdf)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(pdflatex)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(xelatex)'       => [ 'xelatex', 'pdf2ps' ],
+    'ps(lualatex)'       => [ 'lualatex', 'pdf2ps' ],
 );
 
 
@@ -132,7 +126,9 @@ sub new {
     # specified it is taken from that, or the default is take.
 
     my $output = $options->{output};
-    my $format = lc($options->{format});
+    my $format;
+    $format = lc($options->{format})
+        if $options->{format};
 
     if ($output and (!ref $output)) {
         my ($volume, $dir, $file) = File::Spec->splitpath($output);
@@ -216,6 +212,9 @@ sub new {
     my $texinputs_path = $options->{TEXINPUTS} || $options->{texinputs} || [];
     $texinputs_path = [ split(/:/, $texinputs_path) ] unless ref $texinputs_path;
 
+    # see http://tex.stackexchange.com/questions/149714/149865#149865
+
+    my $texinputs_sep = $OSNAME eq "MSWin32" ? ';' : ':';
 
 
     # construct and return the object
@@ -233,7 +232,7 @@ sub new {
                                  capture_stderr => $options->{capture_stderr} || 0,
                                  formatter      => $formatter,
                                  _program_path  => $path,
-                                 texinputs_path => join(':', ('.', @{$texinputs_path}, '')),
+                                 texinputs_path => join($texinputs_sep, ('.', @{$texinputs_path}, '')),
                                  preprocessors  => [],
                                  postprocessors => \@postprocessors,
                                  stats          => { runs => {} } } );
@@ -338,7 +337,7 @@ sub run_latex {
 
     my $basename = $self->basename;
     my $exitcode = $self->run_command($self->formatter =>
-                                      "\\nonstopmode\\def\\TTLATEX{1}\\input{$basename}");
+                                      "\\nonstopmode\\def\\TTLATEX{1}\\input{./$basename}");
 
     # If an error occurred attempt to extract the interesting lines
     # from the log file.  Even without errors the log file may contain
@@ -669,26 +668,33 @@ sub run_command {
     local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
     $self->stats->{runs}{$progname}++;
     debug("running '$program $args'") if $DEBUG;
+    my $cwd = pushd($dir);
 
     # Format the command appropriately for our O/S
 
     my $exit_status;
+    my $exit_error;
+    my ($stdout, $stderr);
     if ($OSNAME eq 'MSWin32') {
         $args = join(' ', @$args);
-        $cmd  = "cmd /c \"cd $dir && $program $args\"";
-        $exit_status = system($cmd);
+        $cmd  = "\"$program\" $args";
+        ($stdout, $stderr) = capture {
+            $exit_status = system($cmd);
+            $exit_error = "$!";
+        };
     }
     else {
         $args = "'$args'" if $args =~ / \\ /mx;
-        my $isc = IPC::ShellCmd->new([$program, @$args])
-            ->working_dir($dir)
-            ->run;
-        $isc->add_timers($self->timeout, 'TERM')
-            if $self->timeout;
-        $self->{stderr} .= $isc->stderr
-            if $self->{capture_stderr};
-        $exit_status = $isc->status;
+        ($stdout, $stderr) = capture {
+            $exit_status = system($program, @$args);
+            $exit_error = "$!";
+        };
     }
+    if ($exit_status == -1) {
+        $self->throw( "Failure to start $program: $exit_error" );
+    }
+    $self->{stderr} .= $stderr
+        if $self->{capture_stderr};
 
     return $exit_status;
 }
@@ -827,7 +833,7 @@ LaTeX::Driver - Latex driver
 
 =head1 VERSION
 
-This document describes version 0.08 of C<LaTeX::Driver>.
+1.0.0
 
 =head1 SYNOPSIS
 
@@ -901,6 +907,42 @@ C<"pdf(dvi)"> (generates PDF via dvi, using C<dvipdfm>).  If not
 specified then the format is determined from the name of the output
 document if specified, or defaults to PDF.
 
+The following list of formats is supported
+
+=over
+
+=item * dvi
+
+=item * ps
+
+=item * postscript
+
+=item * pdf
+
+=item * pdf(pdflatex)
+
+=item * pdf(xelatex)
+
+=item * pdf(lualatex)
+
+=item * ps(xelatex)
+
+=item * ps(lualatex)
+
+=item * pdf(dvi)
+
+=item * pdf(ps)
+
+=item * ps(pdf)
+
+=item * ps(pdflatex)
+
+=item * ps(xelatex)
+
+=item * ps(lualatex)
+
+=back
+
 =item C<tmpdir>
 
 Specifies whether the formatting should be done in a temporary
@@ -1368,14 +1410,15 @@ the web2c TeX distribution, TeX live, tetex, TeX on Windows, etc.
 
 =head1 AUTHOR
 
-Andrew Ford E<lt>a.ford@ford-mason.co.ukE<gt>
-
+   Chris Travers <chris.travers@gmail.com>  (current maintainer)
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2009-2011 Ford & Mason Ltd.  All Rights Reserved.
-
-Copyright (C) 2007 Andrew Ford.  All Rights Reserved.
+   Copyright (C) 2020  Erik Huelsmann.
+   Copyright (C) 2014  Chris Travers.
+   Copyright (C) 2009-2013 Ford & Mason Ltd.
+   Copyright (C) 2006-2007 Andrew Ford.
+   Portions Copyright (C) 1996-2006 Andy Wardley.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
